@@ -19,6 +19,7 @@
 #include <QTimer>
 #include <QDebug>
 #include <QQuickStyle>
+#include <QtWebEngine>
 #include "Dekko.h"
 
 int main(int argc, char** argv)
@@ -26,6 +27,10 @@ int main(int argc, char** argv)
     // set pattern for loggin messages adding date to message text
     qSetMessagePattern("[%{time yyyyMMdd h:mm:ss.zzz t} %{if-category}[%{category}] >> %{endif}%{message}");
 
+    // initialize QtWebEngine, needs to be done before creating dekko view for OpenGL content
+    QtWebEngine::initialize();
+    QCoreApplication::setAttribute(Qt::AA_ShareOpenGLContexts);
+
     Dekko dekko(argc, argv);
 
     if (!dekko.setup()) {
