@@ -281,7 +281,6 @@ void MessageBuilder::buildResponse(const MessageBuilder::ReplyType &type, const
 
 void MessageBuilder::buildForward(const MessageBuilder::ForwardType &type, const QMailMessage &src)
 {
-    Q_UNUSED(type);
     const QString subject = Formatting::mangleForwardSubject(src.subject().simplified());
     if (m_subject == Q_NULLPTR) {
         m_internalSubject->setPlainText(subject);
@@ -290,38 +289,40 @@ void MessageBuilder::buildForward(const MessageBuilder::ForwardType &type, const
     }
 
     QString srcBody = "";
-    bool hasInlineBody(false);
+    bool useInlineBody(false);
 
-    // if message has a plaintext part then we forward it inline
-    if (src.hasPlainTextBody()) {
-        hasInlineBody = true;
-        srcBody = src.body().data();
-    }
-
-    if (src.multipartType() == QMailMessage::MultipartAlternative || src.multipartType() == QMailMessage::MultipartMixed) {
-        QMailMessagePartContainer *ptext = src.findPlainTextContainer();
-        if (ptext) {
-            hasInlineBody = true;
-            srcBody = static_cast<QMailMessagePart *>(ptext)->body().data();
+    if (type == MessageBuilder::ForwardType::Inline) {
+        // if message has a plaintext part then we forward it inline
+        if (src.hasPlainTextBody()) {
+            useInlineBody = true;
+            srcBody = src.body().data();
         }
-    } 
 
-    // if srcBody is still empty then try to use html body
-    if (srcBody.isEmpty() && src.hasHtmlBody()) {
-        QMailMessagePartContainer *htext = src.findHtmlContainer();
-        if (htext) {
-            QMailMessagePart *part = static_cast<QMailMessagePart *>(htext);
-            QTextDocument b;
-            b.setHtml(part->body().data());
-            srcBody = b.toPlainText();
-            hasInlineBody = true;
-        } else {
-            qDebug() << "src.hasHtmlBody() but src.findHtmlContainer() == null. That should never happen!?!";
+        if (src.multipartType() == QMailMessage::MultipartAlternative || src.multipartType() == QMailMessage::MultipartMixed) {
+            QMailMessagePartContainer *ptext = src.findPlainTextContainer();
+            if (ptext) {
+                useInlineBody = true;
+                srcBody = static_cast<QMailMessagePart *>(ptext)->body().data();
+            }
+        } 
+
+        // if srcBody is still empty then try to use html body
+        if (srcBody.isEmpty() && src.hasHtmlBody()) {
+            QMailMessagePartContainer *htext = src.findHtmlContainer();
+            if (htext) {
+                QMailMessagePart *part = static_cast<QMailMessagePart *>(htext);
+                QTextDocument b;
+                b.setHtml(part->body().data());
+                srcBody = b.toPlainText();
+                useInlineBody = true;
+            } else {
+                qDebug() << "src.hasHtmlBody() but src.findHtmlContainer() == null. That should never happen!?!";
+            }
         }
     }
 
     QString body;
-    if (hasInlineBody) {
+    if (useInlineBody) {
         QString forwardBlock = "\n------------ " + tr("Forwarded Message") + " ------------\n";
         forwardBlock += tr("Date: ") + src.date().toString() + '\n';
         forwardBlock += tr("From: ") + src.from().toString() + '\n';
