@@ -36,11 +36,6 @@
         <source>Invalid email address</source>
         <translation>falsk E-Mail Adress</translation>
     </message>
-    <message>
-        <location filename="../Dekko/stores/Accounts/AccountSetup.qml" line="536"/>
-        <source>Sent using Dekko from my Ubuntu device</source>
-        <translation>Sendt mit Smuck van menen Ubuntu Gereedskupp</translation>
-    </message>
 </context>
 <context>
     <name>AccountsWorker</name>
@@ -2222,11 +2217,6 @@ Wullt du düsse bruken?</translation>
 </context>
 <context>
     <name>SmtpAccountConfiguration</name>
-    <message>
-        <location filename="../Dekko/backend/accounts/AccountConfiguration.cpp" line="459"/>
-        <source>Sent using Dekko from my Ubuntu device</source>
-        <translation type="unfinished"></translation>
-    </message>
 </context>
 <context>
     <name>SubjectField</name>
